# Cookbook:: pentester
# Recipe:: autopwn
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

include_recipe 'git'

runtime = node['pentester']['autopwn']['python_runtime'].to_s
runtime_options = node['pentester']['python']['runtime_options'][runtime]

python_runtime runtime do
  options runtime_options if runtime_options
end

python_execute 'install-dependencies' do
  action :nothing
  python runtime
  cwd node['pentester']['autopwn']['install_dir']
  command '-m pip install .'
end

git node['pentester']['autopwn']['install_dir'] do
  repository node['pentester']['autopwn']['git_repository']
  reference node['pentester']['autopwn']['git_reference']
  notifies :run, 'python_execute[install-dependencies]', :immediately
end

targets_dir = "#{node['pentester']['autopwn']['install_dir']}/targets"
directory targets_dir

node['pentester']['autopwn']['targets'].each do |target_name, target_info|
  template "#{targets_dir}/#{target_name}" do
    source 'autopwn/target.erb'
    variables name: target_name,
              info: target_info
  end
end
