# Cookbook:: pentester
# Recipe:: kippo
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

include_recipe 'git'

runtime = node['pentester']['kippo']['python_runtime'].to_s
runtime_options = node['pentester']['python']['runtime_options'][runtime]

python_runtime runtime do
  options runtime_options if runtime_options
end

python_package 'kippo-twisted' do
  action :install
  python runtime
  package_name 'twisted'
  version '15.1.0'
end

python_package 'kippo-pyasn1-pycrypto' do
  action :install
  python runtime
  package_name %w(pyasn1 pycrypto)
end

git node['pentester']['kippo']['install_dir'] do
  action :sync
  repository node['pentester']['kippo']['git_repository']
  reference node['pentester']['kippo']['git_reference']
end

template "#{node['pentester']['kippo']['install_dir']}/kippo.cfg" do
  owner 'root'
  group 'root'
  mode '0644'
  source 'kippo.cfg.erb'
  variables config: node['pentester']['kippo']['config']
end

datadir = "#{node['pentester']['kippo']['install_dir']}/#{node['pentester']['kippo']['config']['data_path']}"
txtcmds = "#{node['pentester']['kippo']['install_dir']}/#{node['pentester']['kippo']['config']['txtcmds_path']}"

file "#{datadir}/userdb.txt" do
  owner 'root'
  group 'root'
  mode '0644'
  content node['pentester']['kippo']['users'].join("\n")
end

node['pentester']['kippo']['txtcmds'].each do |path, content|
  directory "#{txtcmds}/#{::File.dirname(path)}" do
    recursive true
  end

  file "#{txtcmds}/#{path}" do
    owner 'root'
    group 'root'
    mode '0644'
    content content
  end
end
